@@ -154,7 +154,9 @@ class ProxyUpstream:
         req = self._rewrite_to_upstream(request, self._upstream)
         with _session_with_retries() as s:
             try:
-                resp = s.send(req, stream=True)
+                # Merge environment settings into session
+                settings = s.merge_environment_settings(req.url, proxies={}, stream=True, verify=None, cert=None)
+                resp = s.send(req, **settings)
                 resp.raise_for_status()
             except:
                 abort(Response(resp.text, resp.status_code))
@@ -171,7 +173,9 @@ class ProxyUpstream:
             req = self._rewrite_to_upstream(request, self._upstream)
             with _session_with_retries() as s:
                 try:
-                    resp = s.send(req)
+                    # Merge environment settings into session
+                    settings = s.merge_environment_settings(req.url, proxies={}, stream=None, verify=None, cert=None)
+                    resp = s.send(req, **settings)
                     resp.raise_for_status()
                 except requests.exceptions.HTTPError:
                     infoer = current_app.logger.debug if resp.status_code == C.HTTP_NOT_FOUND else current_app.logger.warning
@@ -222,6 +226,7 @@ class ProxyUpstream:
         current_app.logger.info(f"Rewriting '{this_url}' to '{rewritten}'")
 
         headers = {k: v for k, v in request.headers.items() if k not in ['Authorization', 'Host']}
+        headers['Accept'] = 'application/json, */*'
 
         req = requests.Request(method=request.method, url=rewritten, headers=headers, data=request.data)
 
